﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using PrismDemo.Infrastructure;
using PrismDemo.Business;
using Microsoft.Practices.Prism.Commands;
using Microsoft.Practices.Prism.Events;

namespace PrismDemo.Modules.People.Views
{
    public class PeopleViewModel : ViewModelBase
    {
        IEventAggregator _eventAggregator;

        private Person _person;
        public Person Person
        {
            get { return _person; }
            set
            {
                _person = value;
                _person.PropertyChanged += Person_PropertyChanged;
                NotifyPropertyChanged("Person");
            }
        }

        public string Title
        {
            get { return string.Format("{0}, {1}", Person.LastName, Person.FirstName); }
        }

        public DelegateCommand<string> SaveCommand { get; set; }

        public PeopleViewModel(IEventAggregator eventAggregator)
        {
            Person = Person.CreatePerson(DateTime.Now.Millisecond % 2);
            SaveCommand = new DelegateCommand<string>(Save, CanSave);

            GlobalCommands.SaveAllCommand.RegisterCommand(SaveCommand);

            _eventAggregator = eventAggregator;
        }

        private void Save(string value)
        {
            Person.LastUpdated = DateTime.Now.AddYears(Int32.Parse(value));
            _eventAggregator.GetEvent<PersonUpdatedEvent>().Publish(String.Format("{0}, {1}", Person.LastName, Person.FirstName));
        }

        private bool CanSave(string value)
        {
            return Person.Error == null;
        }

        void Person_PropertyChanged(object sender, System.ComponentModel.PropertyChangedEventArgs e)
        {
            SaveCommand.RaiseCanExecuteChanged();
        }
    }
}
